/********************************
	i8088 Error Code definition
*******************************/

#define OK 		 					0
#define ID_ERROR 					-1
#define SLOT_OUT_RANGE			-2
#define CHANNEL_OUT_RANGE		-3
#define SELECT_CHANNEL_ERROR 	-4
#define HI_DUTY_OUT_RANGE		-5
#define LO_DUTY_OUT_RANGE		-6
#define MEMORY_NOT_ENOUGH		-7
#define DISABLE_OVERWRITE		-8
#define NOT_SUPPORT				-99


#ifdef _8088W_EXPORTS
	#define I8088_API __declspec(dllexport)
#else
	#define I8088_API __declspec(dllimport)
#endif

#ifdef	__cplusplus  // for C++ compile use
extern "C" {
#endif	/*	__cplusplus	*/

#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_GetFirmwareVersion(int slot);
/*************************************
	Function to get the Lattice version.
		[input] slot : 0 ~ 7
		[output] return: firmware version
*************************************/


#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_GetLibVersion(void);
/*************************************
	Function used to get the library version.
		[output] return: version number.
				 For example: 0x106 = Rev:1.0.6
*************************************/


#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_GetLibDate(char *LibDate);
/*************************************
	Function used to get the library built date.
		libDate: library built date
*************************************/



#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_Init(int slot);
/*************************************
	Function used to initialize I-8088W at specific slot.
		[input] slot : 0 ~ 7
		[output] return: Error Code.
*************************************/


#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_SetPWMDuty(int slot,int ch,unsigned long hz,unsigned int duty);
/********************************
	Function used to output PWM
		[input] slot : 0 ~ 7
				ch : 0 ~ 7
				hz : 1 ~ 500000 Hz
				duty : 1~99
		[output] return: Error Code.
*******************************/



#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_SetPWMDuty_Deci(int slot,int ch,unsigned long deci_Hz,unsigned int deci_duty);
/********************************
	Function used to output PWM
		[input] slot : 0 ~ 7
				ch : 0 ~ 7
				deci_Hz : 1 ~ 5000000 , 10 means 1 hz ; 5000000 means 500000 Kz
				duty : 1~999 , 250 means 25% ; 600 means 60%
		[output] return: Error Code.

	Note: i8088W_SetPWMDuty_Deci is the same as i8088W_SetPWMDuty_float in usage.
		  but, i8088W_SetPWMDuty_Deci can run more fast than i8088W_SetPWMDuty_float in MiniOS7 conrollers.
*******************************/



#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_SetPWMDuty_Float(int slot,int ch,float f_Hz,float f_Duty);
/********************************
	Function used to output PWM
		[input] slot : 0 ~ 7
				ch : 0 ~ 7
				deci_Hz : 1.0 ~ 500000.0
				duty : 0.1~99.9
		[output] return: Error Code.

	Note: i8088W_SetPWMDuty_Deci is the same as i8088W_SetPWMDuty_float in usage.
		  but, i8088W_SetPWMDuty_Deci can run more fast than i8088W_SetPWMDuty_float in MiniOS7 conrollers.
*******************************/



#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_SetPWMDutyCount(int slot,int ch,unsigned long highDutyCount,unsigned long lowDutyCount);
/********************************
	Function used to output PWM
		[input] slot : 0 ~ 7
				ch : 0 ~ 7
				highDutyCount : 1*1us ~ 65536*128 us
				lowDutyCount : 1*1us ~ 65536*128 us
		[output] return: Error Code.
						  ____________________
	Note: PWM Duty Count |			          |____________________|
						  1*1us~65536*128 us   1*1us~65536*128 us
*******************************/



#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_SetPWMCountMode(int slot,int ch,unsigned char countMode);
/********************************
	Function used to set PWM output mode
		[input] slot : 0 ~ 7
				ch : 0 ~ 7
				countMode : 0 => Burst mode ,1 => Continuos mode
		[output] return: Error Code.
	Note: if set PWM output as Burst mode , please refer to i8088W_SetBurstCount to set burst counts
*******************************/


#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_SetBurstCount(int slot,int ch,unsigned int burstCount);
/********************************
	Function used to set burst count
		[input] slot : 0 ~ 7
				ch : 0 ~ 7
				burstCount : 1 ~ 65536
		[output] return: Error Code.
*******************************/


#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_PWM_Start(int slot,int ch);
/********************************
	Function used to strt PWM output
		[input] slot : 0 ~ 7
				ch : 0 ~ 7
		[output] return: Error Code.
*******************************/


#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_PWM_Stop(int slot,int ch);
/********************************
	Function used to stop output PWM
		[input] slot : 0 ~ 7
				ch : 0 ~ 7
		[output] return: Error Code.
*******************************/


#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_SetSyncChannel(int slot,int ch,int enBit);
/********************************
	Function used to define specific channels to be synchronously output PWM
		[input] slot : 0 ~ 7
				ch : 0 ~ 7
				enBit : 1 => define the specific channel to output PWM synchronously
						0 => define the specific channel not to output PWM synchronously
		[output] return: Error Code.
*******************************/


#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_GetSyncChannel(int slot,int syncArr[]);
/********************************
	Function used to get the specific synchronous channel as bit array
		[input] slot : 0 ~ 7
		[output] syncArr[] : syncArr[0]=1 means channel 0 is defined to be synchronously output PWM
							 syncArr[1]=0 means channel 1 is not defined to be synchronously output PWM
				 return: Error Code.
*******************************/



#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_Sync_Start(int slot);
/********************************
	Function used to strt synchronously output PWM
		[input] slot : 0 ~ 7
		[output] return: Error Code.
*******************************/

#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_Sync_Stop(int slot);
/********************************
	Function used to stop synchronously output PWM
		[input] slot : 0 ~ 7
		[output] return: Error Code.
*******************************/

#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_SetHardwareTrigChannel(int slot,int ch,int enBit);
/********************************
	Function used to define DI channel as a hardware trigger to start or stop the corresponding PWM channel
		[input] slot : 0 ~ 7
				ch : 0 ~ 7
				enBit : 0 => disabled hardware trigger
						1 => configure DI channel as a hardware start trigger
						1 => configure DI channel as a hardware stop trigger
						ex: "i8088W_SetHardwareTrigChannel(slot,0,1);" means set DI0 as a hardware start trigger to start PWM0
		[output] return: Error Code.
*******************************/

#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_GetHardwareTrigChannel(int slot,int ch,int *triggerState);
/********************************
	Function used to get the definition of DI channel
		[input] slot : 0 ~ 7
				ch : 0 ~ 7
		[output] *triggerState : 0 => disabled hardware trigger
								 1 => DI channel has been configured as a hardware start trigger
								 2 means DI channel has been configured as a hardware stop trigger
				 return: Error Code.
*******************************/

#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_GetDI(int slot,unsigned int *diVal,int diArr[]);
/********************************
	Function used to get DI status
		[input] slot : 0 ~ 7
		[output] *diVal : 0 ~ 0xff ,DI status
				 diArr[] : the *DI value will be parse into Bit Array
				 return: Error Code.
*******************************/

#ifdef _WIN32_WCE
	I8088_API
#endif
short i8088W_GetPWMActiveState(int slot,unsigned int *State,int ActiveArr[]);
/********************************
	Function used to get DI status
		[input] slot : 0 ~ 7
		[output] *State : 0 ~ 0xff ,PWM output status
				 ActiveArr[] : the *State value will be parse into Bit Array
				 return: Error Code.
*******************************/
#ifdef	__cplusplus
}
#endif	/*	__cplusplus	*/
